@@ -31,6 +31,11 @@ class DescribeAssetDetailByUuidsRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_Lang(self): # String
+		return self.get_query_params().get('Lang')
+
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
 	def get_Uuids(self): # String
 		return self.get_query_params().get('Uuids')
 
