@@ -51,6 +51,11 @@ class DescribeCloudCenterInstancesRequest(RpcRequest):
 
 	def set_LogicalExp(self, LogicalExp):  # String
 		self.add_query_param('LogicalExp', LogicalExp)
+	def get_Lang(self): # String
+		return self.get_query_params().get('Lang')
+
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
 	def get_CurrentPage(self): # Integer
 		return self.get_query_params().get('CurrentPage')
 
