@@ -18,15 +18,21 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdksas.endpoint import endpoint_data
 
 class ModifyWebLockUnbindRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ModifyWebLockUnbind','sas')
+		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ModifyWebLockUnbind')
 		self.set_method('POST')
 
-	def get_Uuid(self):
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+	def get_Uuid(self): # String
 		return self.get_query_params().get('Uuid')
 
-	def set_Uuid(self,Uuid):
-		self.add_query_param('Uuid',Uuid)
\ No newline at end of file
+	def set_Uuid(self, Uuid):  # String
+		self.add_query_param('Uuid', Uuid)
