@@ -25,40 +25,35 @@ class StartBaselineSecurityCheckRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'StartBaselineSecurityCheck')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_ItemIdss(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_ItemIdss(self): # RepeatList
 		return self.get_query_params().get('ItemIds')
 
-	def set_ItemIdss(self, ItemIdss):
-		for depth1 in range(len(ItemIdss)):
-			if ItemIdss[depth1] is not None:
-				self.add_query_param('ItemIds.' + str(depth1 + 1) , ItemIdss[depth1])
-
-	def get_Type(self):
+	def set_ItemIdss(self, ItemIds):  # RepeatList
+		for depth1 in range(len(ItemIds)):
+			self.add_query_param('ItemIds.' + str(depth1 + 1), ItemIds[depth1])
+	def get_Type(self): # String
 		return self.get_query_params().get('Type')
 
-	def set_Type(self,Type):
-		self.add_query_param('Type',Type)
-
-	def get_SourceIp(self):
+	def set_Type(self, Type):  # String
+		self.add_query_param('Type', Type)
+	def get_SourceIp(self): # String
 		return self.get_query_params().get('SourceIp')
 
-	def set_SourceIp(self,SourceIp):
-		self.add_query_param('SourceIp',SourceIp)
-
-	def get_Lang(self):
+	def set_SourceIp(self, SourceIp):  # String
+		self.add_query_param('SourceIp', SourceIp)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
